'''
'''

from dash import html


class _Base():
    '''
    Return "body" wrapped by html.section tag.
    body - children dash components layout
    prefix - part of id; must be unique
    min_height - CSS property "min-height"
    background_color - CSS property "background-color"
    '''

    def __init__(self, body, prefix: str, min_height: str, background_color: str = None):

        self._body = body
        self._prefix = prefix

        self._style = {
            'min-height': min_height
        }
        self._min_height = min_height
        if background_color:
            self._style['background-color'] = background_color
        self._background_color: background_color

        self._class_name = 'w-100 d-flex align-items-center'

    @property
    def style(self):
        '''
        '''
        return self._style

    @style.setter
    def style(self, style: dict):
        self._style = style

    @property
    def background_color(self):
        '''
        '''
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        self._background_color = background_color
        self._style['background-color'] = background_color

    @property
    def min_height(self):
        '''
        '''
        return self._min_height

    @min_height.setter
    def height(self, min_height):
        self._min_height = min_height
        self._style['min-height'] = min_height

    @property
    def class_name(self):
        '''
        '''
        return self.class_name

    @class_name.setter
    def class_name(self, class_name):
        self._class_name = class_name

    def __call__(self):
        '''
        '''
        layout = html.Section(
            self._body,
            id=f'{self._prefix}-section',
            key=f'{self._prefix}-section',
            className=self._class_name,
            style=self._style
        )

        return layout
